#[non_exhaustive]pub enum DragLockState {
Disabled,
EnabledTimeout,
}Expand description
Drag lock state
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Disabled
Drag lock is to be disabled, or is currently disabled
EnabledTimeout
Drag lock is to be enabled in timeout mode, or is currently enabled in timeout mode